stackspotai

package
v1.60.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 25, 2026 License: MIT Imports: 12 Imported by: 0

Documentation

Overview

* ChatCLI - Command Line Interface for LLM interaction * Copyright (c) 2024 Edilson Freitas * License: MIT

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type StackSpotClient

type StackSpotClient struct {
	// contains filtered or unexported fields
}

StackSpotClient implementa o cliente para interagir com a API de Agente da StackSpot

func NewStackSpotClient

func NewStackSpotClient(tokenManager token.Manager, agentID string, logger *zap.Logger, maxAttempts int, backoff time.Duration) *StackSpotClient

NewStackSpotClient cria uma nova instância de StackSpotClient.

func (*StackSpotClient) GetModelName

func (c *StackSpotClient) GetModelName() string

GetModelName retorna o nome do modelo de linguagem utilizado pelo cliente.

func (*StackSpotClient) SendPrompt

func (c *StackSpotClient) SendPrompt(ctx context.Context, prompt string, history []models.Message, maxTokens int) (string, error)

SendPrompt envia um prompt para o Agente e retorna a resposta direta.

Jump to