Documentation
¶
Overview ¶
* ChatCLI - Command Line Interface for LLM interaction * Copyright (c) 2024 Edilson Freitas * License: Apache-2.0
Index ¶
- type Client
- func (c *Client) GetModelName() string
- func (c *Client) LastStopReason() string
- func (c *Client) LastUsage() *models.UsageInfo
- func (c *Client) ListModels(ctx context.Context) ([]client.ModelInfo, error)
- func (c *Client) SendPrompt(ctx context.Context, prompt string, history []models.Message, maxTokens int) (string, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
func NewClient ¶
func NewClient(baseURL, model string, logger *zap.Logger, maxAttempts int, backoff time.Duration) *Client
NewClient cria uma nova instância de Client para Ollama. Agora sem fallback interno: usa apenas os params passados (vindos do manager/ENVs).
func (*Client) GetModelName ¶
func (*Client) LastStopReason ¶ added in v1.99.0
LastStopReason returns the stop reason from the most recent API call.
func (*Client) LastUsage ¶ added in v1.99.0
LastUsage returns the token usage from the most recent API call.
func (*Client) ListModels ¶ added in v1.97.0
ListModels fetches available models from the Ollama /api/tags endpoint.
Click to show internal directories.
Click to hide internal directories.