Documentation
¶
Overview ¶
* ChatCLI - Command Line Interface for LLM interaction * Copyright (c) 2024 Edilson Freitas * License: MIT
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type StackSpotClient ¶
type StackSpotClient struct {
// contains filtered or unexported fields
}
StackSpotClient implementa o cliente para interagir com a API de Agente da StackSpot
func NewStackSpotClient ¶
func NewStackSpotClient(tokenManager token.Manager, agentID string, logger *zap.Logger, maxAttempts int, backoff time.Duration) *StackSpotClient
NewStackSpotClient cria uma nova instância de StackSpotClient.
func (*StackSpotClient) GetModelName ¶
func (c *StackSpotClient) GetModelName() string
GetModelName retorna o nome do modelo de linguagem utilizado pelo cliente.
Click to show internal directories.
Click to hide internal directories.