Documentation
¶
Overview ¶
* ChatCLI - Command Line Interface for LLM interaction * Copyright (c) 2024 Edilson Freitas * License: MIT
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CallbackResponse ¶
type StackSpotClient ¶
type StackSpotClient struct {
// contains filtered or unexported fields
}
StackSpotClient implementa o cliente para interagir com a API da StackSpot
func NewStackSpotClient ¶
func NewStackSpotClient(tokenManager *token.TokenManager, slug string, logger *zap.Logger, maxAttempts int, backoff time.Duration) *StackSpotClient
NewStackSpotClient cria uma nova instância de StackSpotClient.
func (*StackSpotClient) GetModelName ¶
func (c *StackSpotClient) GetModelName() string
GetModelName retorna o nome do modelo de linguagem utilizado pelo cliente.
func (*StackSpotClient) SendPrompt ¶
func (c *StackSpotClient) SendPrompt(ctx context.Context, prompt string, history []models.Message) (string, error)
SendPrompt envia um prompt para o modelo de linguagem e retorna a resposta.
type Step ¶
type Step struct {
StepName string `json:"step_name"`
ExecutionOrder int `json:"execution_order"`
Type string `json:"type"`
StepResult StepResult `json:"step_result"`
}
type StepResult ¶
Click to show internal directories.
Click to hide internal directories.